==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/Friend.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef __FRIEND_H
#define __FRIEND_H

#include "types.h"                          // Needed for uchar

#include <wx/string.h>                      // Needed for wxString

class CFile;
class CUpDownClient;

#define	FF_NAME		0x01

class CFriend
{
public:
	CFriend(void);
	CFriend(CUpDownClient* client);
	CFriend( uchar t_m_abyUserhash[16], uint32 tm_dwLastSeen, uint32 tm_dwLastUsedIP, uint32 tm_nLastUsedPort, uint32 tm_dwLastChatted, wxString tm_strName, uint32 tm_dwHasHash);
	~CFriend(void);
	uchar	m_abyUserhash[16];
	uint32	m_dwLastSeen;
	uint32	m_dwLastUsedIP;
	uint32	m_nLastUsedPort;
	uint32	m_dwLastChatted;
	uint32	m_dwHasHash;
	wxString m_strName;

	CUpDownClient* m_LinkedClient;

	void	LoadFromFile(CFile* file);
	void	WriteToFile(CFile* file);
};
#endif

==> xmule-1.10.0.tar.bz2: xmule-1.10.0/src/Friend.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef __FRIEND_H
#define __FRIEND_H

#include <stdint.h>                         // uint16_t
#include <wx/string.h>                      // wxString

class CFile;
class CUpDownClient;

#define	FF_NAME		0x01

class CFile;

class CFriend
{
public:
	CFriend(void);
	CFriend(CUpDownClient* client);
	CFriend( unsigned char t_m_abyUserhash[16], uint32_t tm_dwLastSeen, uint32_t tm_dwLastUsedIP, uint32_t tm_nLastUsedPort, uint32_t tm_dwLastChatted, wxString tm_strName, uint32_t tm_dwHasHash);
	~CFriend(void);
	unsigned char	m_abyUserhash[16];
	uint32_t	m_dwLastSeen;
	uint32_t	m_dwLastUsedIP;
	uint32_t	m_nLastUsedPort;
	uint32_t	m_dwLastChatted;
	uint32_t	m_dwHasHash;
	wxString m_strName;

	CUpDownClient* m_LinkedClient;

	void	LoadFromFile(CFile* file);
	void	WriteToFile(CFile* file);
};
#endif
